In a source-monitoring experiment with two sources, participants study
items from two different sources, A and B. The final memory test consists
of A and B items along with new distractor items, N. Participants are
required to classify each item as A, B, or N. In an experiment at the Department of Psychology, University of Tuebingen,
two source conditions were used in the study phase: In the first one,
subjects had to read items either quietly (think) or aloud (say). In the
second, they wrote them down (write) or read them aloud (say).
The data were analyzed using the multinomial processing tree model of
source monitoring (Batchelder & Riefer, 1990).