Learn R Programming

psychotools (version 0.2-0)

plot.RaschModel: Visualizing Simple Rasch Models

Description

Base graphics plotting function for Rasch models.

Usage

## S3 method for class 'RaschModel':
plot(x, difficulty = TRUE,
  center = TRUE, index = TRUE, names = NULL, abbreviate = FALSE, ref = TRUE,
  col = cbind("lightgray", "black"), refcol = "lightgray", linecol = "black", lty = 2,
  cex = 1, pch = cbind(19, 1), type = NULL, ylim = NULL, xlab = "Items", ylab = NULL, ...)

Arguments

x
an object of class "RaschModel".
difficulty
logical. Should item difficulty (or alternatively: easiness) parameters be displayed?
center
logical. Should the item parameters be centered?
index
logical. Should different indexes for different items be used?
names
logical. Should the names for the objects be displayed?
abbreviate
logical or numeric. Should object names be abbreviated? If numeric this controls the length of the abbreviation.
ref
logical. Should a horizontal line for the reference level be drawn?
col, pch, cex
graphical appearance of plotting symbols. Can be of the same length as number of items. Additionally col and pch can be matrices with two columns resulting in two symbols being overplotted.
refcol
line color for reference line (if ref).
linecol
line color.
lty
line type.
type
plot type. Default is "b" if index is TRUE.
ylim
y axis limits.
xlab, ylab
x and y axis labels.
...
further arguments passed to plot.

See Also

RaschModel.fit