RSModel.fit is a basic fitting function for rating scale models.RSModel.fit(y, weights = NULL, start = NULL, reltol = 1e-10,
deriv = c("sum", "diff"), hessian = TRUE,
maxit = 100L, full = TRUE, ...)as.matrix). Typically either already a
matrix or a data.frameFALSE, the vcov method can only return NAs
and consequently no standard errors or tests are available in the
summary.optim.FALSE,
no variance-covariance matrix and no matrix of estimating functions are computed.RSModel.fit returns an S3 object of class "RSModel",
i.e., a list with components as follows."RaschModel" or "btReg", where
data contains the original data,ncol(y), which
indicates which items have variance (TRUE), i.e., are identified and have been
used for the estimation or not (FALSE),ncol(y), which
contains the number of categories minus one per item,y,optim,optim,optim.RSModel.fit provides a basic fitting function for rating scales models,
intended as a building block for fitting rating scale trees.
RSModel.fit returns an object of class "RSModel" (and
class "PCModel") for which several basic methods
are available, including print, plot,
summary, coef, vcov, and logLik.PCModel.fit, RaschModel.fit, btReg.fit## Verbal aggression data
data("VerbalAggression", package = "psychotools")
## Rating scale model for the other-to-blame situations
rsm <- RSModel.fit(VerbalAggression$resp[, 1:12])
summary(rsm)
plot(rsm)Run the code above in your browser using DataLab